@@ -127,8 +127,8 @@ var GetLastPipeline = func(client *gitlab.Client, repo string, ref string) (*git
 	}
 
 	l := &gitlab.ListProjectPipelinesOptions{
-		Ref:  gitlab.String(ref),
-		Sort: gitlab.String("desc"),
+		Ref:  gitlab.Ptr(ref),
+		Sort: gitlab.Ptr("desc"),
 	}
 
 	l.Page = 1
@@ -257,8 +257,8 @@ var GetPipelineFromBranch = func(client *gitlab.Client, ref, repo string) ([]*gi
 		}
 	}
 	l := &gitlab.ListProjectPipelinesOptions{
-		Ref:  gitlab.String(ref),
-		Sort: gitlab.String("desc"),
+		Ref:  gitlab.Ptr(ref),
+		Sort: gitlab.Ptr("desc"),
 	}
 	l.Page = 1
 	l.PerPage = 1
@@ -381,7 +381,7 @@ var PipelineJobsWithSha = func(client *gitlab.Client, pid interface{}, sha strin
 		client = apiClient.Lab()
 	}
 	pipelines, err := GetPipelines(client, &gitlab.ListProjectPipelinesOptions{
-		SHA: gitlab.String(sha),
+		SHA: gitlab.Ptr(sha),
 	}, pid)
 	if len(pipelines) == 0 || err != nil {
 		return nil, nil, err
@@ -438,6 +438,14 @@ var CreatePipeline = func(client *gitlab.Client, projectID interface{}, opts *gi
 	return pipe, err
 }
 
+var RunPipelineTrigger = func(client *gitlab.Client, projectID interface{}, opts *gitlab.RunPipelineTriggerOptions) (*gitlab.Pipeline, error) {
+	if client == nil {
+		client = apiClient.Lab()
+	}
+	pipe, _, err := client.PipelineTriggers.RunPipelineTrigger(projectID, opts)
+	return pipe, err
+}
+
 var DownloadArtifactJob = func(client *gitlab.Client, repo string, ref string, opts *gitlab.DownloadArtifactsFileOptions) (*bytes.Reader, error) {
 	if client == nil {
 		client = apiClient.Lab()
